@@ -447,10 +447,15 @@ int vbox_mm_init(struct vbox_private *vbox)
 #elif RTLNX_VER_MAX(5,2,0) && !RTLNX_RHEL_MAJ_PREREQ(8,2)
 				 DRM_FILE_PAGE_OFFSET,
 #endif
-#if RTLNX_VER_MIN(5,11,0) || RTLNX_RHEL_RANGE(8,5, 8,99)
+#if RTLNX_VER_RANGE(5,11,0, 6,19,0) || RTLNX_RHEL_RANGE(8,5, 8,99)
 				 false,
 #endif
-				 true);
+#if RTLNX_VER_MIN(6,19,0)
+				 TTM_ALLOCATION_POOL_USE_DMA32
+#else
+				 true
+#endif
+				 );
 	if (ret) {
 		DRM_ERROR("Error initialising bo driver; %d\n", ret);
 #if RTLNX_VER_MAX(5,0,0) && !RTLNX_RHEL_MAJ_PREREQ(7,7) && !RTLNX_RHEL_MAJ_PREREQ(8,1)
